#include <bits/stdc++.h>

#define endl '\n'

using namespace std;

typedef long long ll;

const ll MAXN = 1e3 + 10;
const ll MAXLOG = 20;

struct edge
{
    ll u,v,cost,ocost;
    edge()
    {
        u = v = 1;
        cost = 0;
        ocost = 0;
    }
    edge(ll _u, ll _v, ll _cost)
    {
        u = _u;
        v = _v;
        cost = ocost = _cost;
    }
    bool operator<(const edge&e)const
    {
        return cost < e.cost;
    }
};

ll n,q;
vector < edge > edges;
vector < edge > adj[MAXN];
ll lift[MAXN][MAXLOG];
ll lift_max[MAXN][MAXLOG];
ll depth[MAXN];
ll cnt[MAXN];
ll pref[MAXN];
map < ll, ll > compress;
map < ll, ll > compress_back;
ll comp_cnt;
ll max_cost;
set < ll > lens;

void read()
{
    cin >> n >> q;
    for(int i = 1; i < n; i++)
    {
        ll u,v,cost;
        cin >> u >> v >> cost;
        lens.insert(cost);
        edges.push_back(edge(u,v,cost));
        max_cost = max(max_cost, cost);
        ///adj[u].push_back(edge(u,v,cost));
        ///adj[v].push_back(edge(v,u,cost));
    }
}

void compress_cost()
{
    sort(edges.begin(), edges.end());
    for(edge&e : edges)
    {
        ll u = e.u;
        ll v = e.v;
        ll cost = e.cost;

        if(compress.find(cost) == compress.end())
        {
            compress[cost] = ++comp_cnt;
            compress_back[comp_cnt] = cost;
        }

        cost = compress[cost];
        e.cost = cost;
    }

    for(edge e : edges)
    {
        adj[e.u].push_back(e);
        swap(e.u, e.v);
        adj[e.u].push_back(e);
    }
}

void dfs(ll u, ll par, ll cost)
{
    lift[u][0] = par;
    lift_max[u][0] = cost;
    depth[u] = depth[par] + 1;

    for(edge e : adj[u])
    {
        if(e.v == par)
            continue;

        dfs(e.v, u, e.cost);
    }
}

void fill_lift()
{
    dfs(1,1,0);

    for(int j = 1; j < MAXLOG; j++)
    {
        for(int i = 1; i <= n; i++)
        {
            lift[i][j] = lift[lift[i][j - 1]][j - 1];
            lift_max[i][j] = max(lift_max[i][j - 1], lift_max[lift[i][j - 1]][j - 1]);
            /// cout << lift_max[i][j] << " ";
        }
        /// cout << endl;
    }
}

ll find_lca(ll u, ll v)
{
    if(depth[u] < depth[v])
        swap(u, v);

    ll diff = depth[u] - depth[v];

    for(ll j = MAXLOG - 1; j >= 0; j--)
    {
        if(diff >= (1 << j))
        {
            diff -= (1 << j);
            u = lift[u][j];
        }
    }

    if(u == v)
        return u;

    for(ll j = MAXLOG - 1; j >= 0; j--)
    {
        if(lift[u][j] != lift[v][j])
        {
            u = lift[u][j];
            v = lift[v][j];
        }
    }

    return lift[u][0];
}

ll get_max(ll u, ll v)
{
    if(depth[u] < depth[v])
        swap(u, v);

    ll diff = depth[u] - depth[v];

    ll result = 0;

    for(ll j = MAXLOG - 1; j >= 0; j--)
    {
        if(diff >= (1 << j))
        {
            diff -= (1 << j);
            result = max(result, lift_max[u][j]);
            u = lift[u][j];
        }
    }

    return result;
}

ll find_max(ll u, ll v)
{
    ll l = find_lca(u, v);

    return max(get_max(u, l), get_max(v, l));
}

void fill_cnt()
{
    for(int i = 1; i <= n; i++)
    {
        for(int j = i + 1; j <= n; j++)
        {
            ll cur_max = find_max(i, j);
            ll org_max = compress_back[cur_max];

            /// cout << i << " -> " << j << " : " << cur_max << " : " << org_max << endl;

            cnt[cur_max] += org_max;
        }
    }
}

void fill_pref()
{
    for(int i = 1; i <= comp_cnt; i++)
    {
        pref[i] = pref[i - 1] + cnt[i];
        ///cout << pref[i] << " ";
    }
    ///cout << endl;
}

ll query(ll left, ll right)
{
    left = *lens.lower_bound(left);

    left = compress[left];

    if(right > max_cost)
        right = compress[max_cost];
    else
        right = compress[right];

    return pref[right] - pref[left - 1];
}

void process_queries()
{
    for(int i = 1; i <= q; i++)
    {
        ll left, right;
        cin >> left >> right;

        cout << query(left, right) << endl;
    }
}

int main()
{
    ios_base :: sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);

    read();
    compress_cost();
    fill_lift();
    fill_cnt();
    fill_pref();
    process_queries();

    return 0;
}
