#include <iostream>
#include <vector>
#include <unordered_map>
#include <stack>

using namespace std;

int findMaxCostRoad(unordered_map<int, vector<pair<int, int>>>& graph, int start, int end) {
    unordered_set<int> visited;
    stack<int> s;
    s.push(start);
    int maxCost = 0;
    while (!s.empty()) {
        int node = s.top();
        s.pop();
        if (visited.find(node) == visited.end()) {
            visited.insert(node);
            for (auto& neighbor : graph[node]) {
                if (neighbor.first == end) {
                    maxCost = max(maxCost, neighbor.second);
                } else {
                    s.push(neighbor.first);
                }
            }
        }
    }
    return maxCost;
}

vector<int> calculateTolls(int N, vector<vector<int>>& roads, vector<vector<int>>& queries) {
    unordered_map<int, vector<pair<int, int>>> graph;
    for (auto& road : roads) {
        int u = road[0];
        int v = road[1];
        int w = road[2];
        graph[u].push_back({v, w});
        graph[v].push_back({u, w});
    }

    unordered_map<pair<int, int>, int> maxCosts;
    for (int i = 1; i <= N; i++) {
        for (int j = i + 1; j <= N; j++) {
            maxCosts[{i, j}] = findMaxCostRoad(graph, i, j);
        }
    }

    vector<int> result;
    for (auto& query : queries) {
        int l = query[0];
        int r = query[1];
        int totalCost = 0;
        for (auto& cost : maxCosts) {
            if (l <= cost.second && cost.second <= r) {
                totalCost += cost.second;
            }
        }
        result.push_back(totalCost);
    }
    return result;
}

int main() {
    int N, Q;
    cin >> N >> Q;
    vector<vector<int>> roads(N - 1, vector<int>(3));
    vector<vector<int>> queries(Q, vector<int>(2));
    for (int i = 0; i < N - 1; i++) {
        cin >> roads[i][0] >> roads[i][1] >> roads[i][2];
    }
    for (int i = 0; i < Q; i++) {
        cin >> queries[i][0] >> queries[i][1];
    }

    vector<int> costs = calculateTolls(N, roads, queries);
    for (int cost : costs) {
        cout << cost << endl;
    }

    return 0;
}
